Skip to contents

Forecast the target variable from a fitted bridge() model.

Usage

# S3 method for class 'bridge'
forecast(object, xreg = NULL, level = c(80, 95), ...)

# S3 method for class 'bridge_forecast'
print(x, ...)

Arguments

object

A "bridge" object returned by bridge().

xreg

Optional future regressors in a tsbox::ts_boxable() format. When omitted, the forecast set stored inside object is used. When supplied, xreg must contain the same regressor names used when fitting the bridge equation.

level

Confidence levels used for bootstrap predictive intervals when the model was estimated with se = TRUE. When uncertainty is unavailable, forecast() still returns the se, lower, and upper components, filled with NA.

...

Unused.

x

A "bridge_forecast" object returned by forecast.bridge().

Value

An object of class "bridge_forecast" and "forecast" containing point forecasts, bootstrap predictive uncertainty summaries, the target-period regressors used for forecasting, and bootstrap metadata.

x, invisibly.