Forecast the target variable from a fitted bridge() model.
Arguments
- object
A
"bridge"object returned bybridge().- xreg
Optional future regressors in a
tsbox::ts_boxable()format. When omitted, the forecast set stored insideobjectis used. When supplied,xregmust contain the same regressor names used when fitting the bridge equation.- level
Confidence levels used for bootstrap predictive intervals when the model was estimated with
se = TRUE. When uncertainty is unavailable,forecast()still returns these,lower, anduppercomponents, filled withNA.- ...
Unused.
- x
A
"bridge_forecast"object returned byforecast.bridge().